@@ -2,7 +2,7 @@ package Juju::Environment;
 BEGIN {
   $Juju::Environment::AUTHORITY = 'cpan:ADAMJS';
 }
-$Juju::Environment::VERSION = '2.001_1';
+$Juju::Environment::VERSION = '2.002';
 # ABSTRACT: Exposed juju api environment
 
 
@@ -11,6 +11,7 @@ use JSON::PP;
 use YAML::Tiny qw(Dump);
 use Function::Parameters;
 use Juju::Util;
+use Juju::Error::Environment;
 use namespace::autoclean;
 with 'Juju::RPC';
 
@@ -69,7 +70,12 @@ method login {
 
     # block
     my $res = $self->call($params);
-    die $res->{Error} if defined($res->{Error});
+    if (defined($res->{Error})) {
+        Juju::Error::Environment->throw(
+            error_message => 'Failed to login: ' . $res->{Error},
+            method_name   => 'login'
+        );
+    }
     $self->is_authenticated(1)
       unless !defined($res->{Response}->{EnvironTag});
 }
@@ -887,7 +893,7 @@ Juju::Environment - Exposed juju api environment
 
 =head1 VERSION
 
-version 2.001_1
+version 2.002
 
 =head1 SYNOPSIS
 
